from tkinter import *
import math,cmath,time
from tkinter.messagebox import showerror
from disreport import DisReport
import numpy as np

class MkReport():
	""" class MkReport is a continuation of the NetAna application.
	This part writes the output results for both the AC and DC analysis.
	"""
	def __init_(self,parent):
		self.parent = parent
		self.lfreq = []  # Save values for plotting
		self.lmag = []
		self.lpa = []

	def mkreport(self):
		try:
			if not isinstance(self.NetDict['VG'],float):
				raise TypeError
		except TypeError:
			self.showerror('Error','VG must be of type float')

		self.AcDc = 'DC'
		for key in self.NetDict:
			if key[0] in ['L','C']: self.AcDc='AC'


		# Start evaluating equations
		with open(self.ReportFile, 'w', encoding='utf-8') as self.ofile:
			self.matvalues = self.EvalEqu(self.Mat)   # Convert Equation string to values
			print ("# Analysis Created by 'NetAna'.", file=self.ofile)
			when = time.ctime()
			lend = "\n# Date Created: "+when+"\n#\n\n"
			if self.AcDc == 'AC':
				if self.AnalType == 'Node':
					# AC Node Analysis
					print("# AC Node Analysis of file: {:s}".format(self.FileName), file=self.ofile)
					print("# Report file created: {:s} {:s}".format(self.ReportFile, lend), file=self.ofile)
					self.DoACAnalysis('IG')
				else:
					# AC Mash Analysis
					print("# AC Mash Analysis of file: {:s}".format(self.FileName), file=self.ofile)
					print("# Report file created: {:s} {:s}".format(self.ReportFile, lend), file=self.ofile)
					self.DoACAnalysis('VG')
			else:
				if self.AnalType == 'Node':
					# DC Node Analysis
					print("# DC Node Analysis of file: {:s}".format(self.FileName), file=self.ofile)
					print("# Report file created: {:s} {:s}".format(self.ReportFile, lend),file=self.ofile)
					self.DoDCAnalysis('IG')
				else:
					# DC Mash Analysis
					print("# DC Mash Analysis of file: {:s}".format(self.FileName), file=self.ofile)
					print("# Report file created: {:s} {:s}".format(self.ReportFile, lend), file=self.ofile)
					self.DoDCAnalysis('VG')

			self.ofile.close() # done writing to output file

		# Show Report
		DisReport(self.parent, self.ReportFile)

	def DoACAnalysis(self,source='VG'):
		if source == 'VG':
			uLab = 'i'
			dLab = 'Amps'
		else:
			uLab = 'e'
			dLab = 'Volts'

		if 'IGLIST' in self.NetDict :
			m = self.NetDict['IGLIST']
		elif 'VGLIST' in self.NetDict:
			m = self.NetDict['VGLIST']
		else:
			m = np.zeros(self.Nodes, dtype=(np.complex128))
			# Input 'VG' or 'IG'
			m[0] = np.array(self.NetDict[source], dtype=(np.complex128))

		print('##### Units = {:s} {:s}'.format(dLab, '####\n'), file=self.ofile)
		try:
			fstart, fstop, finc, flab = self.NetDict['FREQ']
		except:
			self.showerror("Error",'"FREQ" not defined!')
		else:
			# Save the Component values in a separate dictonary XCompDict
			self.SaveCompValues()
			# Print Header
			self.FreqUnits = flab # Save freq. units
			s1 = " "*7; s2= " "*4
			print('# Frequency{:s}{:s}Magnitude(db){:s}Phase Angle(deg)'.format(flab,s1,s2), file=self.ofile)
			two_pij = 2*math.pi*1j
			for freq in self.genfreq(fstart, fstop, finc):
				self.lfreq.append(freq)  # Save freq for plotting
				print("{:10.2f}".format(freq), file=self.ofile, end="")
				tox = two_pij*freq
				for n in range(self.Nodes):   # Do all nodes
					# Convert reactive components to reactances
					for key in self.XCompDict:
						if key[0] in ['L','C']:
							self.NetDict[key] = self.XCompDict[key] * tox
					# Convert Equation string to values
					self.matvalues = self.EvalEqu(self.Mat)
					npmat = np.array(self.matvalues, dtype=(np.complex128)) # convert to ndarray (complex)
					# Solve for all voltages or currents.
					determ = npmat.copy() # make a copy of np.mat
					determ[:,n] = m		# Insert m at column n
					num = np.linalg.det(determ)
					dem = np.linalg.det(npmat)
					res = num/dem
					res_key = uLab.upper()+str(n+1)
					self.NetDict[res_key] = res


				# Now finished nodes for this frequency
				# Get User Transfer Function and Evaluate it.
				try:
					stf = self.NetDict['TF']
				except:
					self.showerror("Error",'Transfer Function "TF" not defined!')
					break
				else:
					tf = eval(stf,{},self.NetDict)
					# See if tf is near or eq zero
					# if it is set it to small value
					if abs(tf) < 1.0e-6: tf = complex(1.0e-30, 0.0)
					mag = 20.0*math.log10(abs(tf))
					self.lmag.append(mag)  # Save nag for plotting
					angle = math.degrees(cmath.phase(tf))
					self.lpa.append(angle)  # Save for plotting
					print("{:+20.4f}{:+20.4f}".format(mag, angle ),\
						file=self.ofile)


	def DoDCAnalysis(self,source='VG'):
		if source == 'VG':
			uLab = 'i'
			dLab = 'Amps'
		else:
			uLab = 'e'
			dLab = 'Volts'

		if 'IGLIST' in self.NetDict :
			m = self.NetDict['IGLIST']
		elif 'VGLIST' in self.NetDict:
			m = self.NetDict['VGLIST']
		else:
			m = np.zeros(self.Nodes,dtype=(np.float64))
			m[0] = self.NetDict[source]

		npmat = np.array(self.matvalues, dtype=np.float64)
		dem = np.linalg.det(npmat)
		ans = np.linalg.solve(npmat,m)
		res = list(ans)
		print('#### Units ={:s} {:s}'.format(dLab,'####\n'), file=self.ofile)
		for n in range(self.Nodes):
			reskey = uLab.upper()+str(n+1)
			self.NetDict[reskey] = res[n]
			print('{:s}{:d} = {:g}'.format(uLab,n+1,res[n]), file=self.ofile)
			self.lmag.append(res[n]) # Save mag fpr plotting

		# Write GOALS to Report File
		if 'GOALS' in self.NetDict:
			print(file=self.ofile)	# Write one \n
			for goalnb in range(self.NetDict['GOALS']):
				goalkey = 'GOAL'+ str(goalnb+1)
				goal_result = eval(self.NetDict[goalkey][0],self.NetDict,self.NetDict)
				# Add goal result to dict for goal chaining
				gres = 'GR' + str(goalnb+1)
				self.NetDict[gres] = goal_result
				gUnit = self.NetDict[goalkey][1]
				print('#{:s} = {:g} {:s}\t{}'.format(goalkey, goal_result,\
				 gUnit, self.NetDict[goalkey] ), file=self.ofile)

		self.ofile.close()

		# Display Report
		DisReport(self.parent, self.ReportFile)

	def EvalEqu(self,equ):
		""" Converts the equation strings to numeric values
		by using the function 'eval' on the strings."""
		res = []
		for r in range(len(equ)):
			temp = []
			for c in range(len(equ)):
				try:
					temp.append(eval(equ[r][c],self.NetDict,self.NetDict))
				except:
					self.showerror("error","Equation Syntax Error row = {:s} col = {:s}".format(r,c))
			res.append(temp)

		if self.AcDc == 'AC':
			npres = np.array(res, dtype=np.complex128)
		else:
			npres = np.array(res, dtype=np.float64)
		return npres


	def SaveCompValues(self):
		for key in self.NetDict:
			if key[0] in ['L','C']:
				self.XCompDict[key] = self.NetDict[key]


	def genfreq(self,start,stop,inc):
		""" This method returns the next number in a sequence
		using the Python "yield" statment in order to return one value
		at a time instead of a list all at once.
		call:  genfreq(start, stop, increment)
		"""
		freq = start
		while freq < stop:
			yield freq
			freq += inc





import os
from tkinter import *
from tkinter import ttk
from tkinter.messagebox import showerror

class DisReport():
	def __init__(self,parent,filename,lable=None):
		self.parent=parent
		self.top = parent
		self.fn = filename
		self.top = Toplevel(parent)
		fn = os.path.basename(self.fn)
		self.top.title(fn)
		self.top.geometry('+150+250')
		self.top.grab_set()

		self.top.protocol("WM_DELETE_WINDOW", self.close_dia)
		self.initial_focus = self.show()
		self.parent.wait_window(self.top)


	def show(self):
		if os.path.exists(self.fn):
			tw = Text(self.top)
			scroll =Scrollbar(self.top, command=tw.yview)
			button = ttk.Button(self.top, text='Quit',command=self.close_dia)
			tw.config(yscrollcommand=scroll.set)
			tw.config(borderwidth=3)
			tw.config(state=NORMAL)
			tw.delete(1.0,END)
			with open(self.fn, 'r') as fin:
				while(True):
					line = fin.readline()
					if not line: break
					tw.insert(END,line)
				fin.close()
			tw.config(state=DISABLED)
			scroll.pack(side=RIGHT, fill=Y)
			tw.pack(expand=1,fill=BOTH)
			button.pack(anchor=W, padx=10,pady=2)
		else:
			errmes = 'File ' + self.fn + ' can not be found!'
			showerror('FileOpenError', errmes)


	def close_dia(self, event=None):
		self.top.withdraw()
		self.top.update_idletasks()
		self.parent.focus_set()
		self.top.destroy()




if __name__ == "__main__":

	from tkinter import *
	root = Tk()
	fn = "/home/jim/netana-examples/Wein_Bridge.report"
	dp = DisReport(root,fn)






#! /usr/bin/env python3

import os, time

def mknetf(fn,mat):

	""" This module will write a net file "fn" containing
	equiations and node connection specifications.
	Output: the matrix equations and component connections. 
	Format of the 'net data file example of one line:
		c1+y1+A*ya,3,4   equation, node 3, mutual node 4
		A zero in the third column refers to common or ground.
	Input: fillename(fn) and square matrix of equation strings and
		zero strings('0') repreesenting NO equation. 
	Output: File(fn) of node/mask equations and connections."""


	sz = len(mat)
	with open(fn, 'w') as outf:
		# Write header to output file.
		pn = os.path.basename(fn[:-4])
		date = time.ctime()
		outf.write("# Net file for project: {:s} \n".format(pn))
		outf.write("# Produced by Natana.\n")
		outf.write("# Date: {:s}\n\n".format(date))

		for r in range(sz):
			for c in range(sz):
				mnode = '0'
				if mat[r][c] == '0': continue  # no node equ
				else:
					equstr = mat[r][c] # get node equation
					if r==c : node = str(r+1)   # on diggonal get node n
					else: mnode = str(c+1) # get mutial node number
					outf.write( equstr+','+node+','+mnode+'\n')
                

if __name__ == "__main__":

    mat = [['y1','0','0','0','d2'],
           ['m1','y2','0','0','0'],
           ['0','m2','y3','0','0'],
           ['0','0','m3','y4','0'],
           ['d1','0','0','m4','y5']]

    fn = "./test.net"
    mknetf(fn,mat)

    



#!/usr/bin/python3

from tkinter import *
from netana import *

def main():
	root = Tk()
	root.title('NetAna')
	root.geometry('+100+200')
	app = NetAna(root)
	root.mainloop()
   
if __name__ == "__main__" :
	print("Starting Netana")
	main()
	print("Exiting Netana")



from tkinter import *
from tkinter import ttk

import tkinter.filedialog as tfd
import webbrowser,os

from analize import AnalizeSpec
from equations import Equations
from mkreport import MkReport
from plotutil import matplot


class NetAna(Equations, AnalizeSpec, MkReport):
	def __init__(self, master):
		self.opt = options = {}
		options['defaultextension']='.txt'
		options['filetypes']=[('text files', '.txt')]
		options['parent']=master
		options['title']='Get File Name'
		self.bld_menu(master)
		self.bld_widgets(master)
		self.parent=master
		self.lfreq = []
		self.lmag = []
		self.lpa = []

	def bld_menu(self, master):
		mBar = Menu(master, relief='groove', borderwidth=5)
		filemenu = Menu(mBar, tearoff=0)
		filemenu.add_command(label='SpecFile', underline=0,
			command = self.getspecfn)
		filemenu.add_separator()
		filemenu.add_command(label='Exit',
			underline=0, command=master.destroy)
		mBar.add_cascade(label='File', menu=filemenu)
		helpmenu = Menu(mBar, tearoff=0)
		helpmenu.add_command(label='Doc', underline=0, command=self.helpdoc)
		helpmenu.add_command(label='About', underline=0, command=self.about)
		mBar.add_cascade(label='Help', menu=helpmenu)
		master.config(menu=mBar)

	def bld_widgets(self, master):
		title = ttk.Style()
		title.configure("RED.TLabel", font ='times 18 normal italic', foreground='red' )
		fm = ttk.Frame(master)
		ttk.Label(fm, text="Network Analizer", style="RED.TLabel").grid(sticky=N, pady=10)
		fm.pack()
		fm1 = Frame(master)
		self.fnbtn=ttk.Button(fm1,text='Enter Spec. File Name', command=self.getspecfn)
		self.fnbtn.grid(row=0,column=0, sticky=E+W,padx=5,pady=5)
		self.equbtn=ttk.Button(fm1,text='Enter Network Equations', command=self.getequations)
		self.equbtn.grid(row=0, column=1, sticky=E+W,padx=5,pady=5)

		self.analbtn=ttk.Button(fm1,text='Analize Network',command=self.mkreport)
		self.analbtn.grid(row=1,column=0, sticky=E+W,padx=5,pady=5)
		self.plotbtn=ttk.Button(fm1,text='Plot Network Results',command=self.plot)
		self.plotbtn.grid(row=1, column=1, sticky=E+W,padx=5,pady=5)

		self.Quit=ttk.Button(fm1, text='Quit', command=master.destroy)
		self.Quit.grid(row=2,column=0, sticky=W,padx=5,pady=5)
		fm1.pack(anchor=W)
		master.bind_all('<F1>',self.helpdoc)
		# Set default button state
		self.btnctrl(['!disabled','disabled','disabled','disabled'])


	def getspecfn(self):
		file=tfd.askopenfilename(**self.opt)
		self.FileName=file
		self.ProjectName=os.path.basename(file)
		self.BaseFileName=file[:-4]
		self.EquFileName = self.BaseFileName + '.equ'
		self.ReportFile= self.BaseFileName + '.report'
		self.NetFileName = self.BaseFileName + '.net'
		self.Nodes=0
		self.AcDc=''
		self.AnalType=''
		self.FreqUnits=''
		self.Mat=[]
		self.NetDict={}
		self.XCompDict={}
		self.btnctrl(['disabled','!disabled','disabled','disabled'])

	def getequations(self):
		AnalizeSpec.analize(self)
		Equations.getequ(self)
		self.btnctrl(['!disabled','disabled','!disabled','disabled'])

	def mkreport(self):
		MkReport.mkreport(self)
		self.btnctrl(['!disabled','disabled','disabled','!disabled'])

	def plot(self):
		if  self.AcDc == "AC" :   # Plot AC Response
			matplot(units=self.FreqUnits,ylab=None,
				plotdata = (self.ProjectName,self.lfreq, self.lmag, self.lpa))
		else:  # Plot DC Response
			if self.AnalType == 'Node':
				ylabel = 'Volts'
			else:
				ylabel = 'Amps'
			matplot(units='',ylab=ylabel, plotdata=(self.ProjectName,self.lmag))

	def helpdoc(self,event=None):
		prog_dir = os.path.dirname(sys.argv[0])
		doc = os.path.join(prog_dir, "doc/NetAnaDoc.html")
		webbrowser.open(doc,new=2)

	def about(self,event=None):
		prog_dir = os.path.dirname(sys.argv[0])
		doc = os.path.join(prog_dir, "doc/about.html")
		webbrowser.open(doc,new=2)

	def btnctrl(self,blist):
		assert len(blist) == 4
		self.fnbtn.state([blist[0]])
		self.equbtn.state([blist[1]])
		self.analbtn.state([blist[2]])
		self.plotbtn.state([blist[3]])


def main():      # NetAna startup function
	root = Tk()
	root.title('NetAna')
	root.geometry('+100+200')
	app = NetAna(root)
	root.mainloop()


if __name__ == "__main__" :
	main()



import os
from tkinter.messagebox import showerror
from equations import Equations
from mkreport import MkReport


class AnalizeSpec():

	MashNodeError = "Mashs or Nodes must be defined"

	def __init__(self):
		pass

	def analize(self):   # Collect & Evaluate file spec data
		# Get number of Mashs/Nodes if not defined
		with open(self.FileName) as specfile:
			lines = specfile.readlines()
			for line in lines:
				exec(line.upper(),{},self.NetDict)
		try:
			if 'NODES' in self.NetDict:
				self.Nodes = self.NetDict['NODES']
				self.AnalType='Node'
			elif 'MASHS' in self.NetDict:
				self.Nodes = self.NetDict['MASHS']
				self.AnalType='Mash'
			else:
				raise MashNodeError

		except MashNodeError:
			showerror('Error','Mashs or Nodes must be defined')


		if self.Nodes < 2:
			showerror('Error', 'Enter Number of Mashs or Nodes.\nMust be 2 or higher.', 'Net Size', '2')




from griddialog import *
from getnet import getnet 
from mknetf import mknetf
import pickle
from tkinter.messagebox import showerror

class Equations():

	def cleanup(self,dig):
		if dig.status == "Save":
			self.Mat = dig.get()
			self.SaveEquations()
		if dig.top:	dig.top.destroy()

	def SaveEquations(self):
		# Save Mat Equations to file
		if len(self.Mat) > 1:	# if it has been defined
			mknetf(self.NetFileName,self.Mat)
			pickle.dump(self.Mat, open(self.EquFileName ,'wb'))

	def RestoreEquations(self):
		if os.path.exists(self.EquFileName):
			self.Mat=pickle.load(open(self.EquFileName,'rb'))


	def getequ(self):
		# Build Grid Table and get Equations
		if os.path.exists(self.EquFileName):
			self.RestoreEquations()
			dig = GridDialog(self.parent,self.Mat,collab=self.AnalType)
		elif os.path.exists(self.NetFileName):
			self.Mat = getnet(self.NetFileName)
			dig = GridDialog(self.parent,self.Mat,collab=self.AnalType)
		else:
			dig = GridDialog(self.parent,size=self.Nodes,collab=self.AnalType)
		
		# Always clean up
		self.cleanup(dig)



if __name__ == "__main__":

	import os,pickle
	from tkinter import *

	root = Tk()

	os.chdir('/home/jim/test')


	eq = Equations(root)
	eq.Mat = [[1,2,3,4],
			[5,6,7,8],
			[9,10,11,12],
			[13,14,15,16]]

	eq.AnalType = "Node"
	eq.Nodes=4
	eq.EquFileName = "/home/jim/test/Wein_Bridge.equ"
	#eq.NetFileName = "/home/jim/test/BainterFilter.net"
	eq.EquFileName=""
	#eq.NetFileName=""
	eq.getequ()

	print('Mat = {}'.format(eq.Mat))

	root.mainloop()



#! /usr/bin/env python3


def getnet(fn):
	""" This module will read a net file "fn" containing
	components and node connection specifications. It will
	output the matrix node equations. Format of the 'net'
	data file example of one line:
		c1+y1+A*ya,3,4   equation, node 3, mutual (adjacent node 4
		A zero in the third column refers to common or ground.
	Input: fn = filename of net file (connection list)
	Output: square matrix (list of lists) of size equalto the number of
	voltage nodes."""

	with open(fn, 'r') as equfile:
		nbnodes = 0
		ll = []
		for line in equfile:
			if line[0] == '#' or len(line) < 5: continue
			e,n,m = line.split(',')
			sm = m[:m.find('#')]  # strip off comment
			sm = sm.strip()
			ll.append((e,n,sm))
			if int(n) > nbnodes: nbnodes = int(n)

		# Start building matrix
		mat = [['0' for i in range(nbnodes)] for j in range(nbnodes)]
		for tup in ll:
			e,n,mn = tup
			row = int(n)-1
			if mn == '0':
				col = row
			else:
				col = int(mn)-1
			mat[row][col] = e
		return mat

if __name__ == "__main__":

	mat = getnet("examples/BainterFilter.net")
	for i in range(len(mat)):
		print(mat[i])
	







from tkinter import *
from tkinter import ttk
import os

class GridDialog():
	def __init__(self,parent,matrix=None,size=0,title="Grid Dialog",
		label="Equation Matrix",rowlab="Equ",collab="Node"):
		self.top = Toplevel(parent)
		self.top.title(title)
		self.top.transient(parent)
		self.top.geometry('+150+250')
		self.top.grab_set()
		self.parent = parent
		self.result=None
		self.entdict = {}
		if matrix == None:	# Use default zero display
			self.matrix = None
			self.rows= size
			self.cols = size
		else:
			self.matrix = matrix # Display Matrix passed in
			self.rows = len(matrix)
			self.cols = len(matrix[0])
		self.rowlab = rowlab
		self.collab = collab


		self.top.protocol("WM_DELETE_WINDOW", self.cancel)
		self.initial_focus = self.body(label)
		self.parent.wait_window(self.top)


	def body(self,label):
		f1 = ttk.Frame(self.top, borderwidth=2,relief=GROOVE)
		ttk.Label(f1, text=label, font=('20')).pack(side=TOP, padx=10,pady=10)
		f1.pack()

		# Bulid Column labels
		colwidth=12
		f2 = ttk.Frame(self.top, borderwidth=2, relief=GROOVE)
		ttk.Label(f2,text=None,width=5).grid(row=0, column=0, sticky=W, padx=5, pady=5)
		for c in range(self.cols):
			lab=self.collab + " " + str(c+1)
			ttk.Label(f2, width=colwidth,text=lab).grid(row=0, column=c+1,sticky=W, pady=5)
		f2.pack()
		# Build row labels and entry cells
		self.entdict = {}
		f3 = ttk.Frame(self.top, borderwidth=2, relief=GROOVE)
		for r in range(self.rows):
			lab = self.rowlab + " " + str(r+1)
			ttk.Label(f3, text=lab).grid(row=r, column=0,sticky=W,pady=5)
			for c in range(self.cols):
				if r==c : bgcolor = "Gray80"
				else: bgcolor = "White"
				e = StringVar()
				ent=ttk.Entry(f3,width=12,textvariable=e, background=bgcolor
				  ).grid(row=r,column=c+1,sticky=W,pady=5)
				e.set('0')
				self.entdict[(r,c)] = e
		f3.pack()
		# Add OK and Cancel buttons
		f4 = ttk.Frame(self.top, borderwidth=2, relief=GROOVE)
		ttk.Button(f4, text='Save', command=self.save).pack(side=LEFT,padx=5,pady=5)
		cb=ttk.Button(f4, text='Cancel', command=self.cancel).pack(side=LEFT,padx=5,pady=5)
		self.top.bind("<Escape>", self.cancel)
		f4.pack(anchor=W)

		if self.matrix != None: self._set(self.matrix)


	def _set(self,mat):
		"""Internal Method Only: to set entries in the GridDialog it
		uses the Matrix passed to this method."""
		for r in range(len(mat)):
			for c in range(len(mat[0])):
				f = self.entdict[(r,c)]
				f.set(mat[r][c])


	def get(self):
		"""Method returns matrix (lists of lists) from
		the grid dialog"""
		mat = []
		for r in range(self.rows):
			colmat = []
			for c in range(self.cols):
				f = self.entdict[(r,c)]
				equ = f.get()
				colmat.append(equ)
			mat.append(colmat)
		return mat


	def save(self, event=None):
		self.top.withdraw()
		self.top.update_idletasks()
		self.parent.focus_set()
		self.top.destroy()
		self.status='Save'


	def cancel(self,event=None):
		self.parent.focus_set()
		self.top.destroy()
		self.status="Cancel"











if __name__ == "__main__":
	root = Tk()
	root.title('Root')
	root.geometry('+100+200')

	mat = 	[[0,1,2,3,4],
			[5,6,7,8,9],
			[10,11,12,13,14],
			[15,16,17,18,19],
			[20,21,22,23,24]]

# Display Default Grid (zeros) of size of Mat
	dig = GridDialog(root,size=len(mat))
	# Status shows which Button was used to exit dialog
	# SAVE for Save Button and CANCEL for Cancel button
	print('status = {}'.format(dig.status))
	new_mat = dig.get() # gets latest grid contents
	print('new_mat = {}'.format(new_mat))

	dig.top.destroy() # distroys all refences to dialog

# Display grid with contents of passewd in 'mat'
	dig = GridDialog(root,mat)
	print('status = {}'.format(dig.status))
	new_mat = dig.get()
	print('new_mat = {}'.format(new_mat))

	dig.top.destroy()

	root.mainloop()




#!/usr/bin/env python3

from  setuptools import setup, find_packages
""" This file is used to build the 'NetAna' distrubtion.
    All files in 'examples' directory and all files defined in the MANFEST.in
    template file. """

setup(
      name='netana',
      version = '3.3.0',
      packages=find_packages(),
      zip_safe=True,
      include_package_data = True,
      install_requires = ['pyton3-tk','matplotlib',],
      entry_points = { "gui_scripts" : ["netana=main:main"]},
      scripts = ["cp-examples.sh"],
      package_data={'netana': ['examples/*', 'doc/*',
        'netana-3.2.0-md5sums', 'netana.desktop', 'license', 'change.log', 'copyright' ]},
      author= 'James Bainter',
      maintainer= 'James Bainter',
      author_email= 'bainter8326@gmail.com',
      description= 'Electronic Network Analyzer',
      long_description= 'This program solves electronic AC & DC Mash and Node network equations using matrix algebra.',
      platforms= [ 'Linux', 'MSWindows', 'OSX' ],
      keywords="network circuit node mash analysis",
      classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent" ],
      python_requires='>=3.6',
      url = "https://github.com/jrbainter/netana.git",
      )




#! /usr/bin/env python3
# Python Module to plot the DC/AC Network Response

import os,sys,time
import matplotlib.pyplot as plt


def matplot(units='Hz',ylab=None, plotdata=None):

	if ylab != None :
		matplotdc(ylab,data=plotdata)
	else:
		matplotac(units,data=plotdata)


def matplotdc(ylab,data):
	""" This module formats the commands Matplotlib
	to plot the DC network valuse of a circuit. The only
	parameters required are the Y axis label amd the plot data.
	Plot data contains filename and magnitude data.
	"""
	if ylab == 'Volts':
		xlab = 'Node Number'
	else:
		xlab = 'Mash Number'

	name,mag = data
	plt.title(name)
	plt.ylabel(ylab)
	plt.xlabel(xlab)
	plt.grid(True)
	labs = range(1,len(mag)+1)
	plt.plot(labs, mag, 'r-o')

	# Add timestamp to plot
	ts = time.ctime()
	plt.figtext(0.02,0.015,ts,fontsize=7, ha='left')
	plt.show()
	plt.close('all')

def matplotac(units,data):
	"""
	This module formats the commands required by Matplotlib
	to plot the network analysis response/tansfer fuction
	of an AC network where the output report contains three cols of
	data in the following order: frequency, magnitude (dB),
	and phase angle (degrees). The computed data is passed to this functions.

	This function "matplotac" is called with string such as Hz, Kz, Mz)
	and filename,frequency, magnitude, and phahase angle data.

	call as follows:  plotutil.matplotac(units='Hz', data)
	"""

	name, freq, mag, pa = data
	plt.figure(1)
	plt.subplot(211)
	plt.title(name)
	plt.ylabel('Gain (db)')
	plt.grid(True)
	plt.plot(freq, mag)

	plt.subplot(212)
	plt.ylabel('Phase Angle (Deg.)')
	plt.xlabel('Frequency (' + units[0] + units[1].lower() + ')')
	plt.grid(True)
	plt.plot(freq, pa)
	# Add timestamp to plot
	ts = time.ctime()
	plt.figtext(0.02,0.015,ts,fontsize=7, ha='left')
	plt.show()
	plt.close('all')


